@@ -32,8 +32,7 @@ class ApiRpcClient(object):
 
     @inlineCallbacks
     def _remote_exec(self, task_name, on_result, *args, **kwargs):
-
-        client = Client()
+        client = Client(host=self.host)
         try:
             yield client.connect()
 
